package
Version:
v0.0.0-...-d2923a7
Opens a new window with list of versions in this module.
Published: Jun 8, 2026
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func NewEmailService(host, port, from string) *service
type EmailService interface {
SendEmail(to string) error
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.